==> jc-1.4.0.tar.gz: scm/driver.h <==
// class scm.driver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e1f3d6b0aeb58c31 scm_driver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_driver_H_
#define _JC_scm_driver_H_

// Forward structure declarations
struct _jc_java_io_StreamTokenizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_driver$sub_refs	_jc_scm_driver$sub_refs;
typedef struct _jc_scm_driver$sub_nonrefs	_jc_scm_driver$sub_nonrefs;
typedef struct _jc_scm_driver$refs	_jc_scm_driver$refs;
typedef struct _jc_scm_driver$nonrefs	_jc_scm_driver$nonrefs;
typedef struct _jc_scm_driver$object	_jc_scm_driver$object;

typedef struct _jc_scm_driver$fields_struct	_jc_scm_driver$fields_struct;
typedef const struct _jc_scm_driver$vmethods	_jc_scm_driver$vmethods;
typedef const struct _jc_scm_driver$vtable	_jc_scm_driver$vtable;
typedef const struct _jc_scm_driver$vtype	_jc_scm_driver$vtype;

// Class fields structure
struct _jc_scm_driver$fields_struct {
	struct _jc_java_util_Hashtable$object	*syms;
};
extern _jc_scm_driver$fields_struct _jc_scm_driver$class_fields;

// Constructors
extern void _jc_scm_driver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_driver$object *);

// Static methods
extern void _jc_scm_driver$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern struct _jc_object *_jc_scm_driver$method$readinp$d8ed6c4753f80e83(_jc_env *, struct _jc_java_io_StreamTokenizer$object *);
extern struct _jc_scm_Cell$object *_jc_scm_driver$method$readparen$a6107798ac9f9e25(_jc_env *, struct _jc_java_io_StreamTokenizer$object *);
extern struct _jc_object *_jc_scm_driver$method$readtok$84e01f603217ca65(_jc_env *, struct _jc_java_io_StreamTokenizer$object *);

// Virtual methods structure
struct _jc_scm_driver$vmethods {
};

// Vtable
struct _jc_scm_driver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_driver$vmethods	scm_driver;
};

// Vtype
struct _jc_scm_driver$vtype {
	_jc_type			type;
	_jc_scm_driver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_driver$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_driver$refs {
    _jc_scm_driver$sub_refs	scm_driver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_driver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_driver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_driver$sub_nonrefs	scm_driver;
};

// Object instance structure
struct _jc_scm_driver$object {
	_jc_scm_driver$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_driver$vtype	*vtype;
	_jc_scm_driver$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_driver$vtype _jc_scm_driver$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_driver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_driver$class_object;

#endif	/* _JC_scm_driver_H_ */

==> jc-1.4.6.tar.gz: scm/driver.h <==
// class scm.driver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e1f3d6b0aeb58c31 scm_driver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_driver_H_
#define _JC_scm_driver_H_

// Forward structure declarations
struct _jc_java_io_StreamTokenizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_driver$sub_refs	_jc_scm_driver$sub_refs;
typedef struct _jc_scm_driver$sub_nonrefs	_jc_scm_driver$sub_nonrefs;
typedef struct _jc_scm_driver$refs	_jc_scm_driver$refs;
typedef struct _jc_scm_driver$nonrefs	_jc_scm_driver$nonrefs;
typedef struct _jc_scm_driver$object	_jc_scm_driver$object;

typedef struct _jc_scm_driver$fields_struct	_jc_scm_driver$fields_struct;
typedef const struct _jc_scm_driver$vmethods	_jc_scm_driver$vmethods;
typedef const struct _jc_scm_driver$vtable	_jc_scm_driver$vtable;
typedef const struct _jc_scm_driver$vtype	_jc_scm_driver$vtype;

// Class fields structure
struct _jc_scm_driver$fields_struct {
	struct _jc_java_util_Hashtable$object	*syms;
};
extern _jc_scm_driver$fields_struct _jc_scm_driver$class_fields;

// Constructors
extern void _jc_scm_driver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_driver$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_scm_driver$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_scm_driver$method$readinp$d8ed6c4753f80e83(_jc_env *, struct _jc_java_io_StreamTokenizer$object *) _JC_JCNI_ATTR;
extern struct _jc_scm_Cell$object *_jc_scm_driver$method$readparen$a6107798ac9f9e25(_jc_env *, struct _jc_java_io_StreamTokenizer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_scm_driver$method$readtok$84e01f603217ca65(_jc_env *, struct _jc_java_io_StreamTokenizer$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_scm_driver$vmethods {
};

// Vtable
struct _jc_scm_driver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_driver$vmethods	scm_driver;
};

// Vtype
struct _jc_scm_driver$vtype {
	_jc_type			type;
	_jc_scm_driver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_driver$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_driver$refs {
    _jc_scm_driver$sub_refs	scm_driver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_driver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_driver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_driver$sub_nonrefs	scm_driver;
};

// Object instance structure
struct _jc_scm_driver$object {
	_jc_scm_driver$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_driver$vtype	*vtype;
	_jc_scm_driver$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_driver$vtype _jc_scm_driver$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_driver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_driver$class_object;

#endif	/* _JC_scm_driver_H_ */
